%----------------------------------------------------
% Income growth dynamics and polarization
% (using the method by Quah (1996, 1997))
%----------------------------------------------------
clear;
tic
%--------------------------
% Initial parameter values
%--------------------------

alpha   =   1.6;                % alpha parameter for polarization index
h1      =   1;                  % bandwidth const for pdf of y1 (initial inc)
h2      =   1;                  % bandwidth const for pdf of y2 (final inc)
gd_max  =   2.5;
gd_min  =   0.3;
gd      =   linspace(gd_min,gd_max,100)';        % common grid for pdfs  
                                
gn      =   length(gd);         % number of grid points
Iter    =   500;                % number of iterations
P1      =   1;                 % selected year1
P2      =   4;                 % selected year2
P3      =   6;                % selected year3
P4      =   11;
P5      =   101;
P6      =   Iter;

%-------------------------------
% Data loading (balanced panel)
%-------------------------------
y0      =   load('PI_plus_A_transfer.txt');
[~,c]   =   size(y0);
y0      =   y0(:,2:end);

[n,t]   =   size(y0);           

a=25;
t1      =   [1,2,3,4,5];     
t2      =   [6,7,8,9,10];  

%%%%%%%%% average
inc = y0; 
ii = find(inc<0);
inc(ii) = NaN;


inc0 = zeros(n,10);
inc0(:,1:5) = inc(:,1:5);
inc0(:,6:10) = inc(:,24:28);

for j = 1:10
    count = zeros(n,1);
    rinc = zeros(n,1);
    ii = find(inc0(:,j)>0);
    count(ii)=1;
    rinc(ii)=inc0(ii,j);
    sum_count = sum(count);
    sum_rinc = sum(rinc);
    mean_inc = sum_rinc/sum_count;
    inc0(:,j) = inc0(:,j)/mean_inc;
end

per1=prctile(inc0,1);
per99=prctile(inc0,99.0);

inc00 = ones(n,10)*-999;
ii = find(inc0>0);
inc00(ii) = inc0(ii);
inc1 = inc00(:,1);
inc2 = inc00(:,2);

for j = 1:10
    ii2 = find(inc0(:,j)<per1(:,j));
    ii3 = find(inc0(:,j)>per99(:,j));
    inct = inc00(:,j);
    inct(ii2) = -999;
    inct(ii3) = -999; 
    inc00(:,j) = inct;
end

y0 = inc00;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nn  = [];                   % tm * 1: effective sample size
pk  = zeros(gn,gn);         % gn * gn: (avg) probability kernel (i.e., conditional pdf)
p1a = zeros(gn,1);          % gn * 1: (avg) pdf of y1 obtained by marginal avg of joint pdf
p2a = zeros(gn,1);          % gn * 1: last pdf of y2 obtained by marginal avg of joint pdf
npe = [];                   % tm * dim(gdly): NW-nonparametric estimates over gd

tm  = length(t1);
Min = zeros(1,length(t1));
Max = zeros(1,length(t2));


X12 = [];
for tj = 1 : tm
    t1j = t1(tj);
    t2j = t2(tj);
    
    y1  = y0(:,t1j);        % N*1, pick the initial year
    y2  = y0(:,t2j);        % N*1, pick the final year
    
    d1  = logical(y1>0);    % exclude missing = -999 and 0 values
    d2  = logical(y2>0); 
    ind = d1+d2;
    dd  = d1+d2;
    dd  = (dd==2);
    nj  = sum(dd)';          % number of effective/balanced obs
    nn  = [nn; nj];
    
    y1  = y1(ind==2);       % Balanced nominal HH total income
    y2  = y2(ind==2);        
    x1  = y1./(mean(y1));
    x2  = y2./(mean(y2));
    
    x12 = [x1 x2];
    f12 = kerdenfg2(x12,[h1;h2],gd);    
    
    f1a = mean(f12,2);      % marginal pdf of y1 by integrating the joint pdf
    p1a = p1a + f1a;
    p2a = mean(f12,1)';     % merginal pdf of y2 by integrating the joint pdf
    f1  = f1a;
    
    pkj = f12./f1;          % gn*gn conditional pdf
    pk  = pk + pkj;
    
    Min(tj) =min(y1);
    Max(tj) =max(y1);
    
X12 = [X12;x12];
end

pk  = pk/tm;
p1a = p1a/tm;

%---------------------------------------------------------
%   Ergodic pdf: empirically obtained by 5000 iterations
%---------------------------------------------------------

epd0 = p2a;                 % starting point: the pdf of the last period
epd  = [epd0]; epd = epd/mean(epd,1)/gn;
crit = 1;
counter = 1;
while counter < Iter+1
    epd_t = (pk'*epd(:,counter))./gn; epd_t = epd_t/mean(epd_t,1)/gn;
    epd = [epd epd_t];
    crit = abs(norm(epd(:,counter+1))-norm(epd(:,counter)));
    
    counter = counter+1;
end
crit
fprintf('The number of iterations #%d\n', counter-1);
mn   = mean(epd,1);
[~,N]= size(epd);
epd = epd*gn;

epd00  = [epd(:,P1) epd(:,P2) epd(:,P3) epd(:,P4) epd(:,P5) epd(:,counter-1)];     % Pick pdf for report


min1 = find(gd<min(Min(1))); npe(min1,1) = NaN;
max1 = find(gd>max(Max(1))); npe(max1,1) = NaN;
min2 = find(gd<min(Min(2))); npe(min2,2) = NaN;
max2 = find(gd>max(Max(2))); npe(max2,2) = NaN;
min3 = find(gd<min(Min(3))); npe(min3,3) = NaN;
max3 = find(gd>max(Max(3))); npe(max3,3) = NaN;
min4 = find(gd<min(Min(4))); npe(min4,4) = NaN;
max4 = find(gd>max(Max(4))); npe(max4,4) = NaN;
min5 = find(gd<min(Min(5))); npe(min5,5) = NaN;
max5 = find(gd>max(Max(5))); npe(max5,5) = NaN;

year = (1970:1:2017);

GD = zeros(gn,6);
for j = 1:6
    TT = gd.*epd00(:,j);
    if j < 2
        GD(:,j) = gd / mean(TT) ;
        epd00(:,j) = mean(TT)*epd00(:,j);
    else
        GD(:,j) = gd / mean(TT) ;
        epd00(:,j) = mean(TT)*epd00(:,j);
    end
end
M = mean(gd.*epd00(:,6));

cmedian = zeros(gn,gn);
cmedian(:,1) = pk(:,1);
for j = 2:gn
    cmedian(:,j) = cmedian(:,j-1)+pk(:,j);%*gd/100;
end

Median = zeros(gn,1);
for j = 1:gn
    dif = abs(cmedian(j,:)-50*ones(1,100));
    [m,loc] = min(dif);
    Median(j) = gd(loc); %
end
[T,C] = hpfilter(Median,500);


toc;