function [B,seV,G,seVG,W,seW,ER,ERV,STD,STDV]=bipol_var_est(y0)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Inference of Bipo index 
%   by Lee and Shin (2011)
%   (Using 2 groups with the mean as the cutoff point)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% Basic estimate %%%%
n       =   length(y0);
y       =   sort(y0);
ym      =   mean(y0);
ymed    =   median(y);

th      =   0.5;                   % theta = 0.25, 0.5
a       =   1.6;                    % alpha
cut     =   ym;                     % cutoff point of the 2 groups

y1      =   y0(y0<ym);              % low income group
n1      =   length(y1);
p1      =   n1/n;
m1      =   mean(y1);

y2      =   y0(y0>=ym);             % high income group
n2      =   length(y2);
p2      =   n2/n;
m2      =   mean(y2);

d  = MD(y);
d1 = MD(y1);
d2 = MD(y2);

[G,r,L,H]       =   Gini(y);        % Gini for all
[G1,r1,L1,H1]   =   Gini(y1);       % Gini for low income group
[G2,r2,L2,H2]   =   Gini(y2);       % Gini for high income group



B = ((m2-m1)/ym)*p1*p2*((1-th)*(p1/(G1/G))^a + th*(p2/(G2/G))^a);   % Bipol index
W = (m2-m1)/ymed-ym/ymed*G; % Wolfson
ER = ((m2-m1)/2/ym)*p1*p2*((p1)^a + (p2)^a);   % Bipol index
STD = std(y0);


%%%% One-Sample Jackknife Variance Estimate %%%%
V   =   0;
VG  =   0;
i   =   1;
WV = 0;
ERV = 0;
STDV = 0;

while i < n
    yi = y(i);
    mi = ((n*ym)-yi)/(n-1);
    Gi = (2*(sum(L)-L(i)-H(i))/(mi*(n-1)*(n-1))) - n/(n-1);
    yyi = y;
    yyi(i)=[];
    ymedi = median(yyi);
    STDi = std(yyi);
    if yi < cut
        p1i = (n1-1)/(n-1);
        m1i = (n1*m1 - yi)/(n1-1);
        m2i = m2;
        G1i = (2*(sum(L1)-L1(i)-H1(i))/(m1i*(n1-1)*(n1-1))) - n1/(n1-1);
        G2i = G2;
    else
        p1i = n1/(n-1);
        m1i = m1;
        m2i = (n2*m2 - yi)/(n2-1);
        G1i = G1;
        G2i = (2*(sum(L2)-L2(i-n1)-H2(i-n1))/(m2i*(n2-1)*(n2-1))) - n2/(n2-1);
    end
    Bi = (1-(m1i/mi))*p1i*((1-th)*(p1i/(G1i/Gi))^a + th*((1-p1i)/(G2i/Gi))^a);
    Vi = ((n-1)/n)*((Bi-B)^2);
    Wi = (m2i-m1i)/ymedi-mi/ymedi*Gi;
    ERi = ((m2i-m1i)/2/mi)*p1i*(1-p1i)*((p1i)^a + (1-p1i)^a); %1.972
    
    
    V = V + Vi;                         % Jackknife-Var of Bipol
    VG = VG + ((n-1)/n)*((Gi-G)^2);     % Jackknife-Var of Gini
    WV = WV + ((n-1)/n)*((Wi-W)^2);     % Wolfson
    ERV = ERV + ((n-1)/n)*((ERi-ER)^2);     % ER
    STDV = STDV+((n-1)/n)*((STDi-STD)^2);     % ER
    i = i+1;
    

end

seV=V^0.5;
seVG=VG^0.5;
seW = WV^0.5;
ERV = ERV^0.5;
STDV = STDV^0.5;
